slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDGetImplicitTranspose

Gets the mode used to handle the transpose of the matrix associated with the singular value problem.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDGetImplicitTranspose(SVD svd,PetscBool *impl)

Not Collective

### Input Parameter

| svd | - the singular value solver context

### Output Parameter

| impl | - how to handle the transpose (implicitly or not)

### See Also

SVDSetImplicitTranspose(), SVDSolve(), SVDSetOperators()

### Level

advanced

### Location

src/svd/interface/svdopts.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages